<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package minimalblog
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="http://gmpg.org/xfn/11">
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'minimalblog' ); ?></a>
	<?php 
	if (get_theme_mod('prealoader_on_off', 'false') == true) {
		?>
			<div id="preloader" style="background-image: url(<?php echo esc_url(get_theme_mod('prealoader_image'));?>);"></div>
		<?php
	}
	$getlayout = get_theme_mod( 'minimalblog_body_layout', 'fulid' );
	$class = '';
	if ('box' == $getlayout) {
		$class = ' boxlayout';
	}
	 ?>
<div id="page" class="site<?php echo esc_attr( $class );?>">
	
<?php
$getheaderlayout = get_theme_mod( 'header_layout', 'one' );
get_template_part( 'template-parts/header', $getheaderlayout );
$headerimage = (has_header_image() ? get_header_image() : '');

$page_main_title = wp_title( '', false );
if (is_search()) {
	$page_main_title = sprintf( esc_html__( 'Search Results for: %s', 'minimalblog' ), '<span>' . get_search_query() . '</span>' );
}elseif (is_home()) {
	$page_main_title = get_theme_mod( 'blog_header_custom_title', __( 'Our Awesome Blog', 'minimalblog' ));
}

$page_header_show = '';
$blog_header = get_theme_mod( 'blog_page_header' );
if ((is_home() || is_single() ) && $blog_header == 'classic') {
	$page_header_show = true;

}else{
	if (is_page_template('fullwidth.php')) {
		$page_header_show = true;
	}elseif (is_page_template( 'blankpage.php' )) {
		$page_header_show = false;
	}elseif ((class_exists('woocommerce') && is_woocommerce()) && $blog_header == 'classic') {
		$page_header_show = true;
	}
}
if ($page_header_show == true) :
?>
 <div class="page-banner-area" style="background-image: url(<?php echo esc_url($headerimage);?>);">
    <div class="container">
        <div class="row">
            <div class="col-md-12 text-center">
                <div class="page-banner-text">
                    <h1 class="entry-title"><?php echo wp_kses_post( $page_main_title ); ?></h1>
                    <nav>
                        <div class="breadcrumb">
                            <?php
                            if(function_exists('bcn_display') && !is_front_page()) {
                                    bcn_display();
                                }
                            ?>
                        </div>
                    </nav>
                </div>
            </div>
        </div>
    </div>
</div>
<?php endif; ?>
<div id="content" class="site-content">